/* lorien.h 

 Constants and type declarations for for Lorien.

 Chris Eleveld      (The Insane Hermit)
 Robert Slaven      (The Celestial Knight/Tigger)
 Jerry Bolton, Jr.  (Creel)
 Dave Mott          (Energizer Rabbit)

*/

#ifndef _LORIEN_H_
#define _LORIEN_H_

#ifndef _LORIEN_C_
extern size_t MAXCONN;
#else
size_t MAXCONN;
#endif

#include "utility.h"

/* two constants for strcontains() */
#define EXACT 1
#define SUB 2
#define REGEX 4 /* not yet implemented */

#define VERSION         "1.7.2g"   /* the version number. */
#define BUFSIZE		2048	/* the maximum line length to be recieved */
#define OBUFSIZE	BUFSIZE + 80 /* bigger so formatting can occur. */
#define HNAMELEN	80	/* maximum host name length */
#define MAXARGS 	4	/* the maximum number of args on a cmd line */
#define NUMLVL		6	/* the maximum number of security levels */
#define ARCHMAGE	5       /* you got the right one baby */
#define SUPREME		4	/* The level neccessary for ultimate access */
#define SYSOP		3	/* The level neccessary for sysop access */
#define COSYSOP		2	/* The level of a COSYSOP */
#define BABYCO		1	/* this is actually joe user. */
#define JOEUSER		0	/* this person can't do much. */

#define WELCOMEFILE	"lorien.welcome"
#define BLOCKFILE       "lorien.block"
#define HELPFILE        "lorien.help"
#define LOGFILE		"lorien.log"
#define PASSFILE        "lorien.pass"

#define LINE "-------------------------------------------------------------------------------\r\n"

#define MAX_NAME 50
#define MAX_CHAN 13
#ifndef USE_CONFIG_H
#  ifndef DEFCHAN
#    define DEFCHAN  "main"
#  endif
#  ifndef DEFAULT_NAME
#  define DEFAULT_NAME "A nameless newbie"
#  endif
#else
#include "config.h"
#endif


/* values for flags */
#define PLAYER_SHOW	1
#define PLAYER_VRFY	2
#define PLAYER_BEEPS	4
#define PLAYER_MESSAGE	8
#define PLAYER_HUSH	16
#define PLAYER_ECHO	32
#define PLAYER_LEAVING	64
#define PLAYER_WRAP	128
#define PLAYER_INFO     256
#define PLAYER_SCREAM     512

/* macros for flags */
#define CLR_SHOW(p)     (p->flags &= ~PLAYER_SHOW)
#define CLR_VRFY(p)     (p->flags &= ~PLAYER_VRFY)
#define CLR_BEEPS(p)    (p->flags &= ~PLAYER_BEEPS)
#define CLR_MSG(p)      (p->flags &= ~PLAYER_MESSAGE)
#define CLR_HUSH(p)     (p->flags &= ~PLAYER_HUSH)
#define CLR_ECHO(p)     (p->flags &= ~PLAYER_ECHO)
#define CLR_LEAVING(p)  (p->flags &= ~PLAYER_LEAVING)
#define CLR_WRAP(p)     (p->flags &= ~PLAYER_WRAP)
#define CLR_INFO(p)     (p->flags &= ~PLAYER_INFO)
#define CLR_SCREAM(p)     (p->flags &= ~PLAYER_SCREAM)

#define XOR_SHOW(p)     (p->flags ^= PLAYER_SHOW)
#define XOR_VRFY(p)     (p->flags ^= PLAYER_VRFY)
#define XOR_BEEPS(p)    (p->flags ^= PLAYER_BEEPS)
#define XOR_MSG(p)      (p->flags ^= PLAYER_MESSAGE)
#define XOR_HUSH(p)     (p->flags ^= PLAYER_HUSH)
#define XOR_ECHO(p)     (p->flags ^= PLAYER_ECHO)
#define XOR_LEAVING(p)  (p->flags ^= PLAYER_LEAVING)
#define XOR_WRAP(p)     (p->flags ^= PLAYER_WRAP)
#define XOR_INFO(p)     (p->flags ^= PLAYER_INFO)
#define XOR_SCREAM(p)     (p->flags ^= PLAYER_SCREAM)

#define SET_SHOW(p)     (p->flags |= PLAYER_SHOW)
#define SET_VRFY(p)     (p->flags |= PLAYER_VRFY)
#define SET_BEEPS(p)    (p->flags |= PLAYER_BEEPS)
#define SET_MSG(p)      (p->flags |= PLAYER_MESSAGE)
#define SET_HUSH(p)     (p->flags |= PLAYER_HUSH)
#define SET_ECHO(p)     (p->flags |= PLAYER_ECHO)
#define SET_LEAVING(p)  (p->flags |= PLAYER_LEAVING)
#define SET_WRAP(p)     (p->flags |= PLAYER_WRAP)
#define SET_INFO(p)     (p->flags |= PLAYER_INFO)
#define SET_SCREAM(p)     (p->flags |= PLAYER_SCREAM)


#define SHOW(p)     (p->flags & PLAYER_SHOW)
#define VRFY(p)     (p->flags & PLAYER_VRFY)
#define BEEPS(p)    (p->flags & PLAYER_BEEPS)
#define MSG(p)      (p->flags & PLAYER_MESSAGE)
#define HUSH(p)     (p->flags & PLAYER_HUSH)
#define ECHO(p)     (p->flags & PLAYER_ECHO)
#define LEAVING(p)  (p->flags & PLAYER_LEAVING)
#define WRAP(p)     (p->flags & PLAYER_WRAP)
#define INFO(p)     (p->flags & PLAYER_INFO)
#define SCREAM(p)     (p->flags & PLAYER_SCREAM)

/* values for the privs */
#define CANYELL     1
#define CANWHISPER  2
#define CANNAME     4
#define CANCHANNEL  8
#define CANQUIT    16
#define CANCAPS    32
#define CANDEFAULT  CANYELL | CANWHISPER | CANNAME | CANCHANNEL | CANQUIT | CANCAPS 

/* status values */
#define	NONE		0
#define	MESSAGE		1
#define COMMAND		2

#define USAGE	"USAGE: lorien [-l file] [-d] portnumber\nusually just: lorien -d 2525\n"

#define null(p)		(p *) 0
#define new(p)		(p *) malloc(sizeof(p))

#define chan struct channel_struct

struct channel_struct {
   char name[MAX_CHAN + 1]; /* 11th is null character */
   int  secure;
   int  visited;
   int  count;
   chan *next;
}; 

/* types for who list */
#define ALL           (chan *) -3
#define CHANNEL       (chan *) -1	
#define ARRIVAL       (chan *) -2
#define YELL          (chan *) -4
#define INFORMATIONAL (chan *) -6
#define DEPARTURE     (chan *) -5

struct splayer {
    struct splayer *next,*prev;    /* the next player in the linked list */
    int    seclevel;         /* how powerful are they? */
    chan  *chnl;
    int    s;                /* also the line number */
    int    port;             /* remote port number */
    int    hilite;           /* a mask.  */ 
    long   idle;             /* number of seconds since player did anything */
    long   cameon;
    char   onfrom[MAX_NAME]; /* where they are on from */
    char   host[MAX_NAME]; /* where they are really on from */
    char   numhost[MAX_NAME]; /* where they are really on from */
    char   name[MAX_NAME];   /* the player's name */
    fd_set gags;
    int    privs;
#if 0
    int    wrap;
    int    leaving;
#endif
    int    flags; /* hush, etc. */
    char   pbuf[BUFSIZE];
};


#include "ban.h"
#endif
